"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.importSpecs = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = require("fs");
const path_1 = require("path");
const convertSwaggerFile_js_1 = require("./convertSwaggerFile.js");
const generateHooks_js_1 = require("./generateHooks.js");
const generateImports_js_1 = require("./generateImports.js");
const generateSchemas_js_1 = require("./generateSchemas.js");
function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, overrides, }) {
    (0, fs_1.readdir)(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            try {
                const data = (0, fs_1.readFileSync)((0, path_1.join)(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
                const { ext } = (0, path_1.parse)(sourceDirectory + '/' + filename);
                const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
                let spec = await (0, convertSwaggerFile_js_1.convertSwaggerFile)(data, format);
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                const hooksName = `useQueries${filename.split('.')[0]}`;
                const name = filename.split('.')[0];
                (0, fs_1.mkdirSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const operationIds = [];
                let hooks = '';
                let schemaImportsArray = [];
                let collectedQueryImports = [];
                Object.entries(spec.paths).forEach(([route, verbs]) => {
                    Object.entries(verbs).forEach(([verb, operation]) => {
                        if (['get', 'post', 'patch', 'put', 'delete'].includes(verb) && !operation.deprecated) {
                            const { implementation, imports, queryImports } = (0, generateHooks_js_1.createHook)({
                                operation,
                                verb,
                                route: (spec.basePath || '') + route,
                                operationIds,
                                parameters: verbs.parameters,
                                schemasComponents: spec.components,
                                headerFilters,
                                overrides,
                            });
                            hooks += implementation;
                            imports.forEach((element) => {
                                const formattedImport = element.replace('[]', '');
                                if (!schemaImportsArray.includes(formattedImport) &&
                                    element !== 'void' &&
                                    element !== 'string' &&
                                    !element.includes('{')) {
                                    schemaImportsArray.push(formattedImport);
                                }
                            });
                            queryImports.forEach((element) => {
                                if (!schemaImportsArray.includes(element)) {
                                    collectedQueryImports.push(element);
                                }
                            });
                        }
                    });
                });
                const imports = (0, generateImports_js_1.generateImports)({
                    apiDirectory,
                    queryClientDir,
                    schemaName,
                    schemaImports: schemaImportsArray,
                    queryImports: collectedQueryImports,
                });
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), imports + hooks);
                const schemas = (0, generateSchemas_js_1.generateSchemas)({ spec });
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk_1.default.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                if (error.code === 'EISDIR') {
                    console.log(chalk_1.default.red('nested folder structure not supported'));
                    return;
                }
                console.log(chalk_1.default.red(`[${filename}]:`), chalk_1.default.red(error));
            }
        });
    });
}
exports.importSpecs = importSpecs;
